@@ -149,7 +149,7 @@ webkit_pref_callback_user_stylesheet (GSettings  *settings,
 
   user_style_sheet_monitor = g_file_monitor_file (file, G_FILE_MONITOR_NONE, NULL, &error);
   if (!user_style_sheet_monitor) {
-    g_warning ("Could not create a file monitor for %s: %s\n", g_file_get_uri (file), error->message);
+    g_warning ("Could not create a file monitor for %s: %s", g_file_get_uri (file), error->message);
     g_error_free (error);
   } else {
     g_signal_connect (user_style_sheet_monitor, "changed", G_CALLBACK (user_style_sheet_file_changed), NULL);
@@ -256,7 +256,7 @@ webkit_pref_callback_user_javascript (GSettings  *settings,
 
   user_javascript_monitor = g_file_monitor_file (file, G_FILE_MONITOR_NONE, NULL, &error);
   if (!user_javascript_monitor)
-    g_warning ("Could not create a file monitor for %s: %s\n", g_file_get_uri (file), error->message);
+    g_warning ("Could not create a file monitor for %s: %s", g_file_get_uri (file), error->message);
   else
     g_signal_connect (user_javascript_monitor, "changed", G_CALLBACK (user_javascript_file_changed), NULL);
 }
@@ -490,65 +490,93 @@ webkit_pref_callback_hardware_acceleration_policy (GSettings  *settings,
 
 static const PrefData webkit_pref_entries[] = {
   /* Epiphany font settings */
-  { EPHY_PREFS_WEB_SCHEMA,
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_SERIF_FONT,
     "default-font-size",
-    webkit_pref_callback_font_size },
-  { EPHY_PREFS_WEB_SCHEMA,
+    webkit_pref_callback_font_size
+  },
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_MONOSPACE_FONT,
     "default-monospace-font-size",
-    webkit_pref_callback_font_size },
-  { EPHY_PREFS_WEB_SCHEMA,
+    webkit_pref_callback_font_size
+  },
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_SERIF_FONT,
     "default-font-family",
-    webkit_pref_callback_font_family },
-  { EPHY_PREFS_WEB_SCHEMA,
+    webkit_pref_callback_font_family
+  },
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_SANS_SERIF_FONT,
     "sans-serif-font-family",
-    webkit_pref_callback_font_family },
-  { EPHY_PREFS_WEB_SCHEMA,
+    webkit_pref_callback_font_family
+  },
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_MONOSPACE_FONT,
     "monospace-font-family",
-    webkit_pref_callback_font_family },
-  { EPHY_PREFS_WEB_SCHEMA,
+    webkit_pref_callback_font_family
+  },
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_SERIF_FONT,
     "serif-font-family",
-    webkit_pref_callback_font_family },
+    webkit_pref_callback_font_family
+  },
 
-  { EPHY_PREFS_WEB_SCHEMA,
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_USE_GNOME_FONTS,
     NULL,
-    webkit_pref_callback_gnome_fonts },
+    webkit_pref_callback_gnome_fonts
+  },
 
-  { EPHY_PREFS_WEB_SCHEMA,
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_ENABLE_SPELL_CHECKING,
     NULL,
-    webkit_pref_callback_enable_spell_checking },
+    webkit_pref_callback_enable_spell_checking
+  },
 
-  { EPHY_PREFS_WEB_SCHEMA,
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_ENABLE_USER_CSS,
     "user-stylesheet-uri",
-    webkit_pref_callback_user_stylesheet },
-  { EPHY_PREFS_WEB_SCHEMA,
+    webkit_pref_callback_user_stylesheet
+  },
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_ENABLE_USER_JS,
     "user-javascript-uri",
-    webkit_pref_callback_user_javascript },
-  { EPHY_PREFS_WEB_SCHEMA,
+    webkit_pref_callback_user_javascript
+  },
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_LANGUAGE,
     "accept-language",
-    webkit_pref_callback_accept_languages },
-  { EPHY_PREFS_WEB_SCHEMA,
+    webkit_pref_callback_accept_languages
+  },
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_USER_AGENT,
     "user-agent",
-    webkit_pref_callback_user_agent },
-  { EPHY_PREFS_WEB_SCHEMA,
+    webkit_pref_callback_user_agent
+  },
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_ENABLE_WEBSITE_DATA_STORAGE,
     NULL,
-    webkit_pref_callback_enable_website_data_storage },
-  { EPHY_PREFS_WEB_SCHEMA,
+    webkit_pref_callback_enable_website_data_storage
+  },
+  {
+    EPHY_PREFS_WEB_SCHEMA,
     EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY,
     "hardware-acceleration-policy",
-    webkit_pref_callback_hardware_acceleration_policy },
+    webkit_pref_callback_hardware_acceleration_policy
+  },
 };
 
 static gpointer
@@ -556,8 +584,7 @@ ephy_embed_prefs_init (gpointer user_data)
 {
   guint i;
 
-  webkit_settings = webkit_settings_new_with_settings ("enable-back-forward-navigation-gestures", TRUE,
-                                                       "enable-dns-prefetching", TRUE,
+  webkit_settings = webkit_settings_new_with_settings ("enable-developer-extras", TRUE,
                                                        "enable-media-stream", TRUE,
                                                        "enable-smooth-scrolling", TRUE,
                                                        "javascript-can-open-windows-automatically", TRUE,
@@ -584,10 +611,6 @@ ephy_embed_prefs_init (gpointer user_data)
                    EPHY_PREFS_ENABLE_CARET_BROWSING,
                    webkit_settings, "enable-caret-browsing",
                    G_SETTINGS_BIND_GET);
-  g_settings_bind (EPHY_SETTINGS_WEB,
-                   EPHY_PREFS_WEB_SHOW_DEVELOPER_ACTIONS,
-                   webkit_settings, "enable-developer-extras",
-                   G_SETTINGS_BIND_GET);
   g_settings_bind (EPHY_SETTINGS_WEB,
                    EPHY_PREFS_WEB_FONT_MIN_SIZE,
                    webkit_settings, "minimum-font-size",
@@ -600,6 +623,11 @@ ephy_embed_prefs_init (gpointer user_data)
                    EPHY_PREFS_WEB_ENABLE_SITE_SPECIFIC_QUIRKS,
                    webkit_settings, "enable-site-specific-quirks",
                    G_SETTINGS_BIND_GET);
+  g_settings_bind (EPHY_SETTINGS_WEB,
+                   EPHY_PREFS_WEB_ENABLE_NAVIGATION_GESTURES,
+                   webkit_settings, "enable-back-forward-navigation-gestures",
+                   G_SETTINGS_BIND_GET);
+
   return webkit_settings;
 }
 
