@@ -33,6 +33,7 @@
 #include <inttypes.h>
 
 #define ADBLOCK_FILTER_UPDATE_FREQUENCY 24 * 60 * 60 /* In seconds */
+#define ADBLOCK_FILTER_UPDATE_FREQUENCY_METERED 28 * 24 * 60 * 60 /* In seconds */
 #define ADBLOCK_FILTER_SIDECAR_FILE_SUFFIX ".filterinfo"
 
 struct _EphyFiltersManager {
@@ -46,9 +47,10 @@ struct _EphyFiltersManager {
   GCancellable *cancellable;
   WebKitUserContentFilter *wk_filter;
   WebKitUserContentFilterStore *store;
+  gboolean metered;
 };
 
-G_DEFINE_TYPE (EphyFiltersManager, ephy_filters_manager, G_TYPE_OBJECT)
+G_DEFINE_FINAL_TYPE (EphyFiltersManager, ephy_filters_manager, G_TYPE_OBJECT)
 
 enum {
   FILTER_READY,
@@ -230,6 +232,7 @@ sidecar_bytes_loaded_cb (GFile        *file,
   } else {
     g_task_return_error (task, error);
   }
+  g_object_unref (task);
 }
 
 static void
@@ -367,7 +370,7 @@ static GFile *
 filter_info_get_source_file (FilterInfo *self)
 {
   /* It is possible that different Epiphany processes try to download the
-   * same ruleset file simultanously. Using different file names ensures
+   * same ruleset file simultaneously. Using different file names ensures
    * that they do not step on each other toes when writing the downloaded
    * data to disk.
    */
@@ -392,6 +395,8 @@ filter_info_setup_enable_compiled_filter (FilterInfo              *self,
 static gboolean
 filter_info_needs_updating_from_source (const FilterInfo *self)
 {
+  gboolean ret;
+
   g_assert (self);
 
   if (!self->manager)
@@ -426,10 +431,16 @@ filter_info_needs_updating_from_source (const FilterInfo *self)
    * have been last updated to be considered "recent enough" (that is, current
    * time minus the update frequency). Then a filter needs an update if its
    * last update was before that moment. Also check that the "recent enough"
-   * time point can be calculated without undeflowing beforehand.
+   * time point can be calculated without underflowing beforehand.
    */
-  return (self->manager->update_time < ADBLOCK_FILTER_UPDATE_FREQUENCY) ||
-         (self->last_update <= (self->manager->update_time - ADBLOCK_FILTER_UPDATE_FREQUENCY));
+  if (!self->manager->metered)
+    ret = (self->manager->update_time < ADBLOCK_FILTER_UPDATE_FREQUENCY) ||
+          (self->last_update <= (self->manager->update_time - ADBLOCK_FILTER_UPDATE_FREQUENCY));
+  else
+    ret = (self->manager->update_time < ADBLOCK_FILTER_UPDATE_FREQUENCY_METERED) ||
+          (self->last_update <= (self->manager->update_time - ADBLOCK_FILTER_UPDATE_FREQUENCY_METERED));
+
+  return ret;
 }
 
 static void
@@ -569,10 +580,60 @@ filter_info_setup_load_file (FilterInfo *self,
   }
 }
 
+static void
+json_file_deleted (GObject      *source,
+                   GAsyncResult *res,
+                   gpointer      user_data)
+{
+  g_autoptr (GError) error = NULL;
+  if (!g_file_delete_finish (G_FILE (source), res, &error))
+    g_warning ("Could not delete filter json file: %s", error->message);
+}
+
+typedef struct {
+  EphyDownload *download;
+  FilterInfo *self;
+} FilterJsonInfoAsyncData;
+
+static void
+json_file_info_callback (GObject      *source_object,
+                         GAsyncResult *res,
+                         gpointer      user_data)
+{
+  g_autoptr (GError) error = NULL;
+  FilterJsonInfoAsyncData *data = user_data;
+  GFile *json_file = G_FILE (source_object);
+  g_autoptr (GFileInfo) info = g_file_query_info_finish (json_file, res, &error);
+  const char *content_type = NULL;
+
+  if (info)
+    content_type = g_file_info_get_content_type (info);
+  else
+    g_warning ("Couldn't query filter file %s: %s", ephy_download_get_destination (data->download), error->message);
+
+  if (content_type && g_strcmp0 ("application/json", content_type) == 0) {
+    filter_info_setup_load_file (data->self, json_file);
+  } else {
+    g_warning ("Filter source %s has invalid MIME type: %s",
+               ephy_download_get_destination (data->download),
+               content_type);
+
+    g_file_delete_async (json_file, G_PRIORITY_DEFAULT, NULL, json_file_deleted, NULL);
+
+    filter_info_setup_done (data->self);
+  }
+
+  g_object_unref (data->download);
+  g_free (data);
+}
+
 static void
 download_completed_cb (EphyDownload *download,
                        FilterInfo   *self)
 {
+  g_autoptr (GFile) json_file = NULL;
+  FilterJsonInfoAsyncData *data = NULL;
+
   g_assert (download);
   g_assert (self);
 
@@ -580,17 +641,18 @@ download_completed_cb (EphyDownload *download,
 
   LOG ("Filter source %s fetched from <%s>", filter_info_get_identifier (self), self->source_uri);
 
-  if (g_strcmp0 ("application/json", ephy_download_get_content_type (download)) == 0) {
-    g_autoptr (GFile) json_file = g_file_new_for_uri (ephy_download_get_destination_uri (download));
-    filter_info_setup_load_file (self, json_file);
-  } else {
-    g_warning ("Filter source %s has invalid MIME type: %s",
-               ephy_download_get_destination_uri (download),
-               ephy_download_get_content_type (download));
-    filter_info_setup_done (self);
-  }
+  data = g_new0 (FilterJsonInfoAsyncData, 1);
+  data->download = download;
+  data->self = self;
 
-  g_object_unref (download);
+  json_file = g_file_new_for_path (ephy_download_get_destination (download));
+  g_file_query_info_async (json_file,
+                           G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+                           G_FILE_QUERY_INFO_NONE,
+                           G_PRIORITY_DEFAULT,
+                           NULL,
+                           json_file_info_callback,
+                           data);
 }
 
 static void
@@ -626,7 +688,6 @@ filter_load_cb (WebKitUserContentFilterStore *store,
   g_autoptr (GError) error = NULL;
   g_autoptr (GFile) source_file = NULL;
   g_autoptr (GFile) json_file = NULL;
-  g_autofree char *json_file_uri = NULL;
   EphyDownload *download;
 
   if (!self->manager)
@@ -650,7 +711,7 @@ filter_load_cb (WebKitUserContentFilterStore *store,
          filter_info_needs_updating_from_source (self) ? "" : "not ",
          filter_info_get_identifier (self),
          (self->manager->update_time - self->last_update),
-         ADBLOCK_FILTER_UPDATE_FREQUENCY);
+         self->manager->metered ? ADBLOCK_FILTER_UPDATE_FREQUENCY_METERED : ADBLOCK_FILTER_UPDATE_FREQUENCY);
   } else if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
     filter_info_setup_done (self);
     return;
@@ -688,8 +749,7 @@ filter_load_cb (WebKitUserContentFilterStore *store,
   download = ephy_download_new_for_uri_internal (self->source_uri);
 
   json_file = filter_info_get_source_file (self);
-  json_file_uri = g_file_get_uri (json_file);
-  ephy_download_set_destination_uri (download, json_file_uri);
+  ephy_download_set_destination (download, g_file_peek_path (json_file));
   ephy_download_disable_desktop_notification (download);
   webkit_download_set_allow_overwrite (ephy_download_get_webkit_download (download), TRUE);
 
@@ -942,6 +1002,15 @@ update_timeout_cb (EphyFiltersManager *manager)
   return G_SOURCE_CONTINUE;
 }
 
+static void
+on_network_metered (GNetworkMonitor    *monitor,
+                    GParamSpec         *pspec,
+                    EphyFiltersManager *manager)
+
+{
+  manager->metered = g_network_monitor_get_network_metered (g_network_monitor_get_default ());
+}
+
 static void
 ephy_filters_manager_constructed (GObject *object)
 {
@@ -971,7 +1040,10 @@ ephy_filters_manager_constructed (GObject *object)
 
   update_adblock_filter_files_cb (NULL, NULL, manager);
 
-  manager->update_timeout_id = g_timeout_add_seconds (ADBLOCK_FILTER_UPDATE_FREQUENCY,
+  g_signal_connect_object (g_network_monitor_get_default (), "notify::network-metered", G_CALLBACK (on_network_metered), manager, 0);
+  manager->metered = g_network_monitor_get_network_metered (g_network_monitor_get_default ());
+
+  manager->update_timeout_id = g_timeout_add_seconds (manager->metered ? ADBLOCK_FILTER_UPDATE_FREQUENCY_METERED : ADBLOCK_FILTER_UPDATE_FREQUENCY,
                                                       (GSourceFunc)update_timeout_cb,
                                                       manager);
 }
@@ -1052,15 +1124,13 @@ ephy_filters_manager_class_init (EphyFiltersManagerClass *klass)
 
   object_properties[PROP_FILTERS_DIR] =
     g_param_spec_string ("filters-dir",
-                         "Filters directory",
-                         "The directory in which adblock filters are saved",
+                         NULL, NULL,
                          NULL,
                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
   object_properties[PROP_IS_INITIALIZED] =
     g_param_spec_boolean ("is-initialized",
-                          "Filters manager is initialized",
-                          "Whether initialization was completed",
+                          NULL, NULL,
                           FALSE,
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
