@@ -21,8 +21,9 @@
 
 #pragma once
 
-#include <webkit2/webkit2.h>
+#include <webkit/webkit.h>
 
+#include "ephy-autofill-fill-choice.h"
 #include "ephy-embed-shell.h"
 #include "ephy-history-types.h"
 #include "ephy-security-levels.h"
@@ -72,12 +73,19 @@ typedef enum {
   EPHY_WEB_VIEW_ERROR_PROCESS_CRASH,
   EPHY_WEB_VIEW_ERROR_UNRESPONSIVE_PROCESS,
   EPHY_WEB_VIEW_ERROR_INVALID_TLS_CERTIFICATE,
-  EPHY_WEB_VIEW_ERROR_UNSAFE_BROWSING,
   EPHY_WEB_VIEW_ERROR_NO_SUCH_FILE,
 } EphyWebViewErrorPage;
 
-typedef void (* EphyPasswordSaveRequestCallback) (int      response_id,
-                                                  gpointer data);
+typedef enum {
+  EPHY_WEB_VIEW_TLS_ERROR_PAGE_MESSAGE_HANDLER = 1 << 0,
+  EPHY_WEB_VIEW_RELOAD_PAGE_MESSAGE_HANDLER = 1 << 1,
+  EPHY_WEB_VIEW_ABOUT_APPS_MESSAGE_HANDLER = 1 << 2,
+} EphyWebViewMessageHandler;
+
+typedef enum {
+  EPHY_WEB_VIEW_REGISTER_MESSAGE_HANDLER_FOR_CURRENT_PAGE,
+  EPHY_WEB_VIEW_REGISTER_MESSAGE_HANDLER_FOR_NEXT_LOAD
+} EphyWebViewMessageHandlerScope;
 
 GType                      ephy_web_view_chrome_get_type          (void);
 GType                      ephy_web_view_security_level_get_type  (void);
@@ -89,7 +97,7 @@ void                       ephy_web_view_load_url                 (EphyWebView
                                                                    const char                *url);
 gboolean                   ephy_web_view_is_loading               (EphyWebView               *view);
 gboolean                   ephy_web_view_load_failed              (EphyWebView               *view);
-GdkPixbuf *                ephy_web_view_get_icon                 (EphyWebView               *view);
+GIcon *                    ephy_web_view_get_icon                 (EphyWebView               *view);
 EphyWebViewDocumentType    ephy_web_view_get_document_type        (EphyWebView               *view);
 EphyWebViewNavigationFlags ephy_web_view_get_navigation_flags     (EphyWebView               *view);
 const char *               ephy_web_view_get_status_message       (EphyWebView               *view);
@@ -101,9 +109,6 @@ void                       ephy_web_view_set_security_level       (EphyWebView
 const char *               ephy_web_view_get_typed_address        (EphyWebView               *view);
 void                       ephy_web_view_set_typed_address        (EphyWebView               *view,
                                                                    const char                *address);
-gboolean            ephy_web_view_get_should_bypass_safe_browsing (EphyWebView               *view);
-void                ephy_web_view_set_should_bypass_safe_browsing (EphyWebView               *view,
-                                                                   gboolean                   bypass_safe_browsing);
 gboolean                   ephy_web_view_get_is_blank             (EphyWebView               *view);
 gboolean                   ephy_web_view_is_newtab                (EphyWebView               *view);
 gboolean                   ephy_web_view_is_overview              (EphyWebView               *view);
@@ -177,15 +182,28 @@ gboolean                   ephy_web_view_get_reader_mode_state    (EphyWebView
 
 gboolean                   ephy_web_view_is_in_auth_dialog        (EphyWebView               *view);
 
-void                       ephy_web_view_show_auth_form_save_request (EphyWebView                    *web_view,
-                                                                      const char                     *origin,
-                                                                      const char                     *username,
-                                                                      EphyPasswordSaveRequestCallback response_callback,
-                                                                      gpointer                        response_data,
-                                                                      GDestroyNotify                  response_destroy);
-
 GtkWidget                 *ephy_web_view_new_with_user_content_manager (WebKitUserContentManager *ucm);
 
 guint64                    ephy_web_view_get_uid                       (EphyWebView *web_view);
 
+void                       ephy_web_view_get_web_app_manifest_url (EphyWebView         *view,
+                                                                   GCancellable        *cancellable,
+                                                                   GAsyncReadyCallback  callback,
+                                                                   gpointer             user_data);
+char                      *ephy_web_view_get_web_app_manifest_url_finish (EphyWebView   *view,
+                                                                          GAsyncResult  *result,
+                                                                          GError       **error);
+
+void                       ephy_web_view_register_message_handler (EphyWebView                    *view,
+                                                                   EphyWebViewMessageHandler       handler,
+                                                                   EphyWebViewMessageHandlerScope  scope);
+
+void ephy_web_view_autofill                                       (EphyWebView               *view,
+                                                                   const char                *selector,
+                                                                   EphyAutofillFillChoice     fill_choice);
+
+gboolean ephy_web_view_autofill_popup_enabled                     (EphyWebView               *web_view);
+
+void ephy_web_view_autofill_disable_popup                         (EphyWebView               *web_view);
+
 G_END_DECLS
