@@ -59,7 +59,6 @@ Ephy.getWebAppIcon = function(baseURL)
     let msIconURL = null;
     let largestIconSize = 0;
     let iconColor = null;
-    let ogpIcon = null;
     const links = document.getElementsByTagName('link');
     const metas = document.getElementsByTagName('meta');
 
@@ -106,18 +105,12 @@ Ephy.getWebAppIcon = function(baseURL)
             msIconURL = meta.content;
         else if (meta.name === 'msapplication-TileColor')
             iconColor = meta.content;
-        else if (meta.getAttribute('property') === 'og:image' || meta.getAttribute('itemprop') === 'image')
-            ogpIcon = meta.content;
     }
 
     // msapplication icon.
     if (msIconURL)
         return { 'url' : new URL(msIconURL, baseURL).href, 'color' : iconColor };
 
-    // ogp icon.
-    if (ogpIcon)
-        return { 'url' : new URL(ogpIcon, baseURL).href, 'color' : null };
-
     // html icon without known size
     if (htmlIconURL)
         return { 'url' : new URL(htmlIconURL, baseURL).href, 'color' : null };
@@ -897,4 +890,4 @@ window.document.addEventListener('contextmenu', (event) => {
     // isContentEditable is always false, in practice this seems functional enough.
     contextMenuElementIsEditable = event.target.tagName.toLowerCase() === 'input';
     contextMenuElementIsPassword = event.target.type === 'password';
-});
\ No newline at end of file
+});
