@@ -29,7 +29,7 @@
 #include <gio/gsettingsbackend.h>
 #include <stdlib.h>
 #include <string.h>
-#include <webkit2/webkit2.h>
+#include <webkit/webkit.h>
 
 struct _EphyPermissionsManager {
   GObject parent_instance;
@@ -43,7 +43,7 @@ struct _EphyPermissionsManager {
   GSettingsBackend *backend;
 };
 
-G_DEFINE_TYPE (EphyPermissionsManager, ephy_permissions_manager, G_TYPE_OBJECT)
+G_DEFINE_FINAL_TYPE (EphyPermissionsManager, ephy_permissions_manager, G_TYPE_OBJECT)
 
 #define PERMISSIONS_FILENAME "permissions.ini"
 
@@ -154,6 +154,8 @@ ephy_permissions_manager_new (void)
 static const char *
 permission_type_to_string (EphyPermissionType type)
 {
+  g_assert (ephy_permission_is_stored_by_permissions_manager (type));
+
   switch (type) {
     case EPHY_PERMISSION_TYPE_SHOW_NOTIFICATIONS:
       return "notifications-permission";
@@ -174,6 +176,26 @@ permission_type_to_string (EphyPermissionType type)
   }
 }
 
+/* Some permissions do not get remembered by the permissions manager. Generally,
+ * Epiphany prompts every time such permission is requested. But
+ * ACCESS_WEBCAM_AND_MICROPHONE is special: only separate ACCESS_MICROPHONE and
+ * ACCESS_WEBCAM permissions get stored.
+ */
+gboolean
+ephy_permission_is_stored_by_permissions_manager (EphyPermissionType type)
+{
+  switch (type) {
+    case EPHY_PERMISSION_TYPE_ACCESS_WEBCAM_AND_MICROPHONE:
+    /* fallthrough */
+    case EPHY_PERMISSION_TYPE_WEBSITE_DATA_ACCESS:
+    /* fallthrough */
+    case EPHY_PERMISSION_TYPE_CLIPBOARD:
+      return FALSE;
+    default:
+      return TRUE;
+  }
+}
+
 EphyPermission
 ephy_permissions_manager_get_permission (EphyPermissionsManager *manager,
                                          EphyPermissionType      type,
@@ -181,7 +203,7 @@ ephy_permissions_manager_get_permission (EphyPermissionsManager *manager,
 {
   GSettings *settings;
 
-  g_assert (type != EPHY_PERMISSION_TYPE_ACCESS_WEBCAM_AND_MICROPHONE);
+  g_assert (ephy_permission_is_stored_by_permissions_manager (type));
 
   settings = ephy_permissions_manager_get_settings_for_origin (manager, origin);
   return g_settings_get_enum (settings, permission_type_to_string (type));
@@ -263,7 +285,7 @@ ephy_permissions_manager_set_permission (EphyPermissionsManager *manager,
   WebKitSecurityOrigin *webkit_origin;
   GSettings *settings;
 
-  g_assert (type != EPHY_PERMISSION_TYPE_ACCESS_WEBCAM_AND_MICROPHONE);
+  g_assert (ephy_permission_is_stored_by_permissions_manager (type));
 
   webkit_origin = webkit_security_origin_new_for_uri (origin);
   if (webkit_origin == NULL)
