@@ -47,9 +47,9 @@ struct _EphySearchEngineManager {
 static void list_model_iface_init (GListModelInterface *iface,
                                    gpointer             iface_data);
 
-G_DEFINE_TYPE_WITH_CODE (EphySearchEngineManager, ephy_search_engine_manager,
-                         G_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (G_TYPE_LIST_MODEL, list_model_iface_init))
+G_DEFINE_FINAL_TYPE_WITH_CODE (EphySearchEngineManager, ephy_search_engine_manager,
+                               G_TYPE_OBJECT,
+                               G_IMPLEMENT_INTERFACE (G_TYPE_LIST_MODEL, list_model_iface_init))
 
 enum {
   PROP_0,
@@ -238,8 +238,7 @@ ephy_search_engine_manager_class_init (EphySearchEngineManagerClass *klass)
 
   properties [PROP_DEFAULT_ENGINE] =
     g_param_spec_object ("default-engine",
-                         "Default search engine",
-                         "The default search engine for this manager.",
+                         NULL, NULL,
                          EPHY_TYPE_SEARCH_ENGINE,
                          (G_PARAM_READWRITE |
                           G_PARAM_STATIC_STRINGS |
