@@ -109,7 +109,7 @@ ephy_string_shorten (char  *str,
   /* if the string is already short enough, or if it's too short for
    * us to shorten it, return a new copy */
   if ((gsize)actual_length <= target_length)
-    return str;
+    return g_strdup (str);
 
   /* create string */
   bytes = GPOINTER_TO_UINT (g_utf8_offset_to_pointer (str, target_length - 1) - str);
@@ -181,17 +181,18 @@ ephy_string_get_host_name (const char *url)
       g_str_has_prefix (url, "ephy-about:"))
     return NULL;
 
-  uri = g_uri_parse (url, G_URI_FLAGS_NONE, NULL);
+  uri = g_uri_parse (url, G_URI_FLAGS_PARSE_RELAXED, NULL);
   /* If uri is NULL it's very possible that we just got
    * something without a scheme, let's try to prepend
    * 'http://' */
   if (uri == NULL) {
     char *effective_url = g_strconcat ("http://", url, NULL);
-    uri = g_uri_parse (effective_url, G_URI_FLAGS_NONE, NULL);
+    uri = g_uri_parse (effective_url, G_URI_FLAGS_PARSE_RELAXED, NULL);
     g_free (effective_url);
   }
 
-  if (uri == NULL) return NULL;
+  if (uri == NULL)
+    return NULL;
 
   return g_strdup (g_uri_get_host (uri));
 }
@@ -243,23 +244,13 @@ ephy_string_find_and_replace (const char *haystack,
                               const char *to_repl)
 {
   GString *str;
-  const char *tmp;
-  gsize to_find_len;
-  gsize pos;
 
   g_assert (haystack);
   g_assert (to_find);
   g_assert (to_repl);
 
   str = g_string_new (haystack);
-  to_find_len = strlen (to_find);
-
-  while ((tmp = strstr (str->str, to_find)) != NULL) {
-    pos = tmp - str->str;
-    g_string_erase (str, pos, to_find_len);
-    g_string_insert (str, pos, to_repl);
-  }
-
+  g_string_replace (str, to_find, to_repl, 0);
   return g_string_free (str, FALSE);
 }
 
