@@ -79,6 +79,7 @@ typedef struct _EphyHistoryServiceMessage {
   gpointer user_data;
   GCancellable *cancellable;
   GDestroyNotify method_argument_cleanup;
+  GDestroyNotify result_cleanup;
   EphyHistoryJobCallback callback;
 } EphyHistoryServiceMessage;
 
@@ -101,7 +102,7 @@ enum {
 
 static GParamSpec *obj_properties[LAST_PROP];
 
-G_DEFINE_TYPE (EphyHistoryService, ephy_history_service, G_TYPE_OBJECT);
+G_DEFINE_FINAL_TYPE (EphyHistoryService, ephy_history_service, G_TYPE_OBJECT);
 
 static void
 ephy_history_service_set_property (GObject      *object,
@@ -292,15 +293,13 @@ ephy_history_service_class_init (EphyHistoryServiceClass *klass)
 
   obj_properties[PROP_HISTORY_FILENAME] =
     g_param_spec_string ("history-filename",
-                         "History filename",
-                         "The filename of the SQLite file holding containing history",
+                         NULL, NULL,
                          NULL,
                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   obj_properties[PROP_MEMORY] =
     g_param_spec_boolean ("memory",
-                          "In memory mode",
-                          "Whether the history service works in memory mode",
+                          NULL, NULL,
                           FALSE,
                           G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
 
@@ -335,6 +334,7 @@ ephy_history_service_message_new (EphyHistoryService            *service,
                                   EphyHistoryServiceMessageType  type,
                                   gpointer                       method_argument,
                                   GDestroyNotify                 method_argument_cleanup,
+                                  GDestroyNotify                 result_cleanup,
                                   GCancellable                  *cancellable,
                                   EphyHistoryJobCallback         callback,
                                   gpointer                       user_data)
@@ -345,6 +345,7 @@ ephy_history_service_message_new (EphyHistoryService            *service,
   message->type = type;
   message->method_argument = method_argument;
   message->method_argument_cleanup = method_argument_cleanup;
+  message->result_cleanup = result_cleanup;
   message->cancellable = cancellable ? g_object_ref (cancellable) : NULL;
   message->callback = callback;
   message->user_data = user_data;
@@ -358,6 +359,9 @@ ephy_history_service_message_free (EphyHistoryServiceMessage *message)
   if (message->method_argument_cleanup)
     message->method_argument_cleanup (message->method_argument);
 
+  if (message->result_cleanup)
+    message->result_cleanup (message->result);
+
   if (message->cancellable)
     g_object_unref (message->cancellable);
 
@@ -698,6 +702,7 @@ ephy_history_service_add_visit (EphyHistoryService     *self,
   message = ephy_history_service_message_new (self, ADD_VISIT,
                                               ephy_history_page_visit_copy (visit),
                                               (GDestroyNotify)ephy_history_page_visit_free,
+                                              NULL,
                                               cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
@@ -717,6 +722,7 @@ ephy_history_service_add_visits (EphyHistoryService     *self,
   message = ephy_history_service_message_new (self, ADD_VISITS,
                                               ephy_history_page_visit_list_copy (visits),
                                               (GDestroyNotify)ephy_history_page_visit_list_free,
+                                              NULL,
                                               cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
@@ -754,7 +760,10 @@ ephy_history_service_query_visits (EphyHistoryService     *self,
   g_assert (query != NULL);
 
   message = ephy_history_service_message_new (self, QUERY_VISITS,
-                                              ephy_history_query_copy (query), (GDestroyNotify)ephy_history_query_free, cancellable, callback, user_data);
+                                              ephy_history_query_copy (query),
+                                              (GDestroyNotify)ephy_history_query_free,
+                                              (GDestroyNotify)ephy_history_page_visit_list_free,
+                                              cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
 
@@ -783,7 +792,9 @@ ephy_history_service_query_urls (EphyHistoryService     *self,
   g_assert (query != NULL);
 
   message = ephy_history_service_message_new (self, QUERY_URLS,
-                                              ephy_history_query_copy (query), (GDestroyNotify)ephy_history_query_free,
+                                              ephy_history_query_copy (query),
+                                              (GDestroyNotify)ephy_history_query_free,
+                                              (GDestroyNotify)ephy_history_url_list_free,
                                               cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
@@ -799,8 +810,9 @@ ephy_history_service_get_hosts (EphyHistoryService     *self,
   g_assert (EPHY_IS_HISTORY_SERVICE (self));
 
   message = ephy_history_service_message_new (self, GET_HOSTS,
-                                              NULL, NULL, cancellable,
-                                              callback, user_data);
+                                              NULL, NULL,
+                                              (GDestroyNotify)ephy_history_host_list_free,
+                                              cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
 
@@ -818,6 +830,7 @@ ephy_history_service_query_hosts (EphyHistoryService     *self,
   message = ephy_history_service_message_new (self, QUERY_HOSTS,
                                               ephy_history_query_copy (query),
                                               (GDestroyNotify)ephy_history_query_free,
+                                              (GDestroyNotify)ephy_history_host_list_free,
                                               cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
@@ -879,7 +892,7 @@ ephy_history_service_set_url_title (EphyHistoryService     *self,
   url = ephy_history_url_new (orig_url, title, 0, 0, 0);
   message = ephy_history_service_message_new (self, SET_URL_TITLE,
                                               url, (GDestroyNotify)ephy_history_url_free,
-                                              cancellable, callback, user_data);
+                                              NULL, cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
 
@@ -927,7 +940,7 @@ ephy_history_service_set_url_zoom_level (EphyHistoryService     *self,
 
   message = ephy_history_service_message_new (self, SET_URL_ZOOM_LEVEL,
                                               variant, (GDestroyNotify)g_variant_unref,
-                                              cancellable, callback, user_data);
+                                              NULL, cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
 
@@ -969,7 +982,7 @@ ephy_history_service_set_url_hidden (EphyHistoryService     *self,
 
   message = ephy_history_service_message_new (self, SET_URL_HIDDEN,
                                               url, (GDestroyNotify)ephy_history_url_free,
-                                              cancellable, callback, user_data);
+                                              NULL, cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
 
@@ -1000,7 +1013,7 @@ ephy_history_service_get_url (EphyHistoryService     *self,
   g_assert (url != NULL);
 
   message = ephy_history_service_message_new (self, GET_URL,
-                                              g_strdup (url), g_free,
+                                              g_strdup (url), g_free, (GDestroyNotify)ephy_history_url_free,
                                               cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
@@ -1033,7 +1046,7 @@ ephy_history_service_get_host_for_url (EphyHistoryService     *self,
   g_assert (url != NULL);
 
   message = ephy_history_service_message_new (self, GET_HOST_FOR_URL,
-                                              g_strdup (url), g_free,
+                                              g_strdup (url), g_free, (GDestroyNotify)ephy_history_host_free,
                                               cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
@@ -1138,7 +1151,7 @@ ephy_history_service_delete_urls (EphyHistoryService     *self,
 
   message = ephy_history_service_message_new (self, DELETE_URLS,
                                               ephy_history_url_list_copy (urls), (GDestroyNotify)ephy_history_url_list_free,
-                                              cancellable, callback, user_data);
+                                              NULL, cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
 
@@ -1152,7 +1165,7 @@ ephy_history_service_delete_host (EphyHistoryService     *self,
   EphyHistoryServiceMessage *message =
     ephy_history_service_message_new (self, DELETE_HOST,
                                       ephy_history_host_copy (host), (GDestroyNotify)ephy_history_host_free,
-                                      cancellable, callback, user_data);
+                                      NULL, cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
 
@@ -1167,7 +1180,7 @@ ephy_history_service_clear (EphyHistoryService     *self,
   g_assert (EPHY_IS_HISTORY_SERVICE (self));
 
   message = ephy_history_service_message_new (self, CLEAR,
-                                              NULL, NULL,
+                                              NULL, NULL, NULL,
                                               cancellable, callback, user_data);
   ephy_history_service_send_message (self, message);
 }
@@ -1179,7 +1192,7 @@ ephy_history_service_quit (EphyHistoryService     *self,
 {
   EphyHistoryServiceMessage *message =
     ephy_history_service_message_new (self, QUIT,
-                                      NULL, NULL, NULL,
+                                      NULL, NULL, NULL, NULL,
                                       callback, user_data);
   ephy_history_service_send_message (self, message);
 }
