@@ -225,6 +225,7 @@ ephy_sync_debug_prepare_soup_message (const char   *url,
   SyncCryptoHawkOptions *options = NULL;
   SyncCryptoHawkHeader *header;
   SoupMessage *msg;
+  SoupMessageHeaders *request_headers;
   const char *content_type = "application/json";
 
   g_assert (url);
@@ -236,18 +237,23 @@ ephy_sync_debug_prepare_soup_message (const char   *url,
 
   msg = soup_message_new (method, url);
 
+  request_headers = soup_message_get_request_headers (msg);
+
   if (body) {
+    g_autoptr (GBytes) bytes = NULL;
+
     options = ephy_sync_crypto_hawk_options_new (NULL, NULL, NULL, content_type,
                                                  NULL, NULL, NULL, body, NULL);
-    soup_message_set_request (msg, content_type, SOUP_MEMORY_COPY, body, strlen (body));
+    bytes = g_bytes_new (body, strlen (body));
+    soup_message_set_request_body_from_bytes (msg, content_type, bytes);
   }
 
   if (!g_strcmp0 (method, "PUT") || !g_strcmp0 (method, "POST"))
-    soup_message_headers_append (msg->request_headers, "content-type", content_type);
+    soup_message_headers_append (request_headers, "content-type", content_type);
 
   header = ephy_sync_crypto_hawk_header_new (url, method, hawk_id,
                                              hawk_key, hawk_key_len, options);
-  soup_message_headers_append (msg->request_headers, "authorization", header->header);
+  soup_message_headers_append (request_headers, "authorization", header->header);
 
   ephy_sync_crypto_hawk_header_free (header);
   if (options)
@@ -267,7 +273,7 @@ ephy_sync_debug_get_signed_certificate (const char           *session_token,
   JsonObject *json;
   JsonObject *public_key;
   JsonObject *json_body;
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
   guint8 *id;
   guint8 *key;
   guint8 *tmp;
@@ -279,6 +285,7 @@ ephy_sync_debug_get_signed_certificate (const char           *session_token,
   char *e;
   guint status_code;
   g_autofree char *accounts_server = NULL;
+  g_autoptr (GBytes) response_body = NULL;
 
   g_assert (session_token);
   g_assert (keypair);
@@ -304,17 +311,21 @@ ephy_sync_debug_get_signed_certificate (const char           *session_token,
   msg = ephy_sync_debug_prepare_soup_message (url, "POST", body,
                                               id_hex, key, 32);
   session = soup_session_new ();
-  status_code = soup_session_send_message (session, msg);
-
-  if (status_code != 200) {
-    LOG ("Failed to get signed certificate: %s", msg->response_body->data);
+  response_body = soup_session_send_and_read (session, msg, NULL, &error);
+  if (!response_body) {
+    LOG ("Failed to get signed certificate: %s", error->message);
     goto free_session;
   }
 
-  response = json_from_string (msg->response_body->data, &error);
+  status_code = soup_message_get_status (msg);
+  if (status_code != 200) {
+    LOG ("Failed to get signed certificate: %s", (const char *)g_bytes_get_data (response_body, NULL));
+    goto free_session;
+  }
+
+  response = json_from_string (g_bytes_get_data (response_body, NULL), &error);
   if (error) {
     LOG ("Response is not a valid JSON: %s", error->message);
-    g_error_free (error);
     goto free_session;
   }
 
@@ -350,7 +361,7 @@ ephy_sync_debug_get_storage_credentials (char **storage_endpoint,
   JsonNode *response;
   JsonObject *secrets;
   JsonObject *json;
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
   char *certificate;
   char *audience;
   char *assertion;
@@ -360,6 +371,8 @@ ephy_sync_debug_get_storage_credentials (char **storage_endpoint,
   guint8 *kb;
   const char *session_token;
   guint status_code;
+  SoupMessageHeaders *request_headers;
+  g_autoptr (GBytes) response_body = NULL;
   gboolean success = FALSE;
   g_autofree char *token_server = NULL;
 
@@ -381,20 +394,26 @@ ephy_sync_debug_get_storage_credentials (char **storage_endpoint,
   client_state = g_strndup (hashed_kb, 32);
   authorization = g_strdup_printf ("BrowserID %s", assertion);
   msg = soup_message_new ("GET", token_server);
-  soup_message_headers_append (msg->request_headers, "X-Client-State", client_state);
-  soup_message_headers_append (msg->request_headers, "authorization", authorization);
+  request_headers = soup_message_get_request_headers (msg);
+  soup_message_headers_append (request_headers, "X-Client-State", client_state);
+  soup_message_headers_append (request_headers, "authorization", authorization);
   session = soup_session_new ();
-  status_code = soup_session_send_message (session, msg);
-
-  if (status_code != 200) {
-    LOG ("Failed to get storage credentials: %s", msg->response_body->data);
+  response_body = soup_session_send_and_read (session, msg, NULL, &error);
+  if (!response_body) {
+    LOG ("Failed to get storage credentials: %s", error->message);
     goto free_session;
   }
 
-  response = json_from_string (msg->response_body->data, &error);
+  status_code = soup_message_get_status (msg);
+
+  if (status_code != 200) {
+    LOG ("Failed to get storage credentials: %s", (const char *)g_bytes_get_data (response_body, NULL));
+    goto free_session;
+  }
+
+  response = json_from_string (g_bytes_get_data (response_body, NULL), &error);
   if (error) {
     LOG ("Response is not a valid JSON: %s", error->message);
-    g_error_free (error);
     goto free_session;
   }
 
@@ -430,11 +449,12 @@ ephy_sync_debug_send_request (const char *endpoint,
   SoupSession *session;
   SoupMessage *msg;
   char *response = NULL;
-  char *storage_endpoint;
-  char *storage_id;
-  char *storage_key;
+  char *storage_endpoint = NULL;
+  char *storage_id = NULL;
+  char *storage_key = NULL;
   char *url;
   guint status_code;
+  g_autoptr (GBytes) response_body = NULL;
 
   g_assert (endpoint);
   g_assert (method);
@@ -453,12 +473,15 @@ ephy_sync_debug_send_request (const char *endpoint,
                                               (const guint8 *)storage_key,
                                               strlen (storage_key));
   session = soup_session_new ();
-  status_code = soup_session_send_message (session, msg);
+  response_body = soup_session_send_and_read (session, msg, NULL, NULL);
+  status_code = soup_message_get_status (msg);
 
-  if (status_code == 200)
-    response = g_strdup (msg->response_body->data);
-  else
-    LOG ("Failed to send storage request: %s", msg->response_body->data);
+  if (response_body) {
+    if (status_code == 200)
+      response = g_strdup (g_bytes_get_data (response_body, NULL));
+    else
+      LOG ("Failed to send storage request: %s", (const char *)g_bytes_get_data (response_body, NULL));
+  }
 
   g_free (url);
   g_free (storage_endpoint);
@@ -603,7 +626,7 @@ ephy_sync_debug_view_record (const char *collection,
   g_assert (collection);
   g_assert (id);
 
-  id_safe = soup_uri_encode (id, NULL);
+  id_safe = g_uri_escape_string (id, NULL, TRUE);
   endpoint = g_strdup_printf ("storage/%s/%s", collection, id_safe);
   response = ephy_sync_debug_send_request (endpoint, "GET", NULL);
 
@@ -671,7 +694,7 @@ ephy_sync_debug_upload_record (const char *collection,
   if (!bundle)
     return;
 
-  id_safe = soup_uri_encode (id, NULL);
+  id_safe = g_uri_escape_string (id, NULL, TRUE);
   endpoint = g_strdup_printf ("storage/%s/%s", collection, id_safe);
   body = ephy_sync_debug_make_upload_body (id, record, bundle);
   response = ephy_sync_debug_send_request (endpoint, "PUT", body);
@@ -724,7 +747,7 @@ ephy_sync_debug_delete_collection (const char *collection)
   array = json_node_get_array (node);
   for (guint i = 0; i < json_array_get_length (array); i++) {
     const char *id = json_array_get_string_element (array, i);
-    char *id_safe = soup_uri_encode (id, NULL);
+    char *id_safe = g_uri_escape_string (id, NULL, TRUE);
     char *body = ephy_sync_debug_make_delete_body (id, bundle);
     char *to = g_strdup_printf ("storage/%s/%s", collection, id_safe);
     char *resp = ephy_sync_debug_send_request (to, "PUT", body);
@@ -772,7 +795,7 @@ ephy_sync_debug_delete_record (const char *collection,
   if (!bundle)
     return;
 
-  id_safe = soup_uri_encode (id, NULL);
+  id_safe = g_uri_escape_string (id, NULL, TRUE);
   endpoint = g_strdup_printf ("storage/%s/%s", collection, id_safe);
   body = ephy_sync_debug_make_delete_body (id, bundle);
   response = ephy_sync_debug_send_request (endpoint, "PUT", body);
@@ -839,7 +862,7 @@ ephy_sync_debug_erase_record (const char *collection,
   g_assert (collection);
   g_assert (id);
 
-  id_safe = soup_uri_encode (id, NULL);
+  id_safe = g_uri_escape_string (id, NULL, TRUE);
   endpoint = g_strdup_printf ("storage/%s/%s", collection, id_safe);
   response = ephy_sync_debug_send_request (endpoint, "DELETE", NULL);
 
@@ -1029,6 +1052,7 @@ ephy_sync_debug_view_connected_devices (void)
   char *url;
   const char *session_token;
   g_autofree char *accounts_server = NULL;
+  g_autoptr (GBytes) response_body = NULL;
 
   secrets = ephy_sync_debug_load_secrets ();
   if (!secrets)
@@ -1042,9 +1066,10 @@ ephy_sync_debug_view_connected_devices (void)
   id_hex = ephy_sync_utils_encode_hex (id, 32);
   msg = ephy_sync_debug_prepare_soup_message (url, "GET", NULL, id_hex, key, 32);
   session = soup_session_new ();
-  soup_session_send_message (session, msg);
+  response_body = soup_session_send_and_read (session, msg, NULL, NULL);
 
-  LOG ("%s", msg->response_body->data);
+  if (response_body)
+    LOG ("%s", (const char *)g_bytes_get_data (response_body, NULL));
 
   g_object_unref (session);
   g_object_unref (msg);
@@ -1074,7 +1099,7 @@ ephy_sync_debug_get_current_device (void)
   JsonArray *array;
   SoupSession *session;
   SoupMessage *msg;
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
   guint8 *id;
   guint8 *key;
   guint8 *tmp;
@@ -1083,6 +1108,7 @@ ephy_sync_debug_get_current_device (void)
   const char *session_token;
   guint status_code;
   g_autofree char *accounts_server = NULL;
+  g_autoptr (GBytes) response_body = NULL;
 
   secrets = ephy_sync_debug_load_secrets ();
   if (!secrets)
@@ -1096,17 +1122,22 @@ ephy_sync_debug_get_current_device (void)
   id_hex = ephy_sync_utils_encode_hex (id, 32);
   msg = ephy_sync_debug_prepare_soup_message (url, "GET", NULL, id_hex, key, 32);
   session = soup_session_new ();
-  status_code = soup_session_send_message (session, msg);
-
-  if (status_code != 200) {
-    LOG ("Failed to GET account devices: %s", msg->response_body->data);
+  response_body = soup_session_send_and_read (session, msg, NULL, &error);
+  if (!response_body) {
+    LOG ("Failed to GET account devices: %s", error->message);
     goto free_session;
   }
 
-  response = json_from_string (msg->response_body->data, &error);
+  status_code = soup_message_get_status (msg);
+
+  if (status_code != 200) {
+    LOG ("Failed to GET account devices: %s", (const char *)g_bytes_get_data (response_body, NULL));
+    goto free_session;
+  }
+
+  response = json_from_string (g_bytes_get_data (response_body, NULL), &error);
   if (error) {
     LOG ("Response is not a valid JSON: %s", error->message);
-    g_error_free (error);
     goto free_session;
   }
 
