@@ -23,6 +23,9 @@
 
 #include <gtk/gtk.h>
 
+#include "ephy-adaptive-mode.h"
+#include "ephy-bookmark-states.h"
+
 G_BEGIN_DECLS
 
 #define EPHY_TYPE_ACTION_BAR_END (ephy_action_bar_end_get_type ())
@@ -32,6 +35,16 @@ G_DECLARE_FINAL_TYPE (EphyActionBarEnd, ephy_action_bar_end, EPHY, ACTION_BAR_EN
 EphyActionBarEnd *ephy_action_bar_end_new                       (void);
 void              ephy_action_bar_end_set_show_bookmarks_button (EphyActionBarEnd *action_bar_end,
                                                                  gboolean          show);
+void              ephy_action_bar_end_show_downloads            (EphyActionBarEnd *action_bar_end);
 GtkWidget        *ephy_action_bar_end_get_downloads_revealer    (EphyActionBarEnd *action_bar_end);
 
+void              ephy_action_bar_end_set_browser_actions       (EphyActionBarEnd *action_bar_end,
+                                                                 GListStore       *browser_actions);
+
+void              ephy_action_bar_end_set_bookmark_icon_state (EphyActionBarEnd       *action_bar_end,
+                                                               EphyBookmarkIconState  state);
+
+void              ephy_action_bar_end_set_adaptive_mode       (EphyActionBarEnd *action_bar_end,
+                                                               EphyAdaptiveMode  adaptive_mode);
+
 G_END_DECLS
