@@ -29,10 +29,9 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_CERTIFICATE_DIALOG (ephy_certificate_dialog_get_type())
 
-G_DECLARE_FINAL_TYPE (EphyCertificateDialog, ephy_certificate_dialog, EPHY, CERTIFICATE_DIALOG, AdwWindow)
+G_DECLARE_FINAL_TYPE (EphyCertificateDialog, ephy_certificate_dialog, EPHY, CERTIFICATE_DIALOG, AdwDialog)
 
-GtkWidget *ephy_certificate_dialog_new      (GtkWindow           *parent,
-                                             const char          *address,
+AdwDialog *ephy_certificate_dialog_new      (const char          *address,
                                              GTlsCertificate     *certificate,
                                              GTlsCertificateFlags tls_errors,
                                              EphySecurityLevel    security_level);
