@@ -23,7 +23,6 @@
 #include "config.h"
 #include "ephy-header-bar.h"
 
-#include "ephy-add-bookmark-popover.h"
 #include "ephy-desktop-utils.h"
 #include "ephy-embed-utils.h"
 #include "ephy-file-helpers.h"
@@ -257,15 +256,9 @@ ephy_header_bar_constructed (GObject *object)
     adw_bin_set_child (ADW_BIN (event_box), clamp);
   }
 
-  if (EPHY_IS_LOCATION_ENTRY (header_bar->title_widget)) {
-    EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (header_bar->title_widget);
-    GtkWidget *popover = ephy_add_bookmark_popover_new ();
-
-    ephy_location_entry_set_add_bookmark_popover (lentry, GTK_POPOVER (popover));
-  }
-
   /* Fullscreen restore button */
   header_bar->restore_button = gtk_button_new_from_icon_name ("view-restore-symbolic");
+  gtk_widget_set_tooltip_text (header_bar->restore_button, _("Exit Fullscreen"));
   gtk_widget_set_visible (header_bar->restore_button, FALSE);
   gtk_actionable_set_action_name (GTK_ACTIONABLE (header_bar->restore_button),
                                   "win.fullscreen");
@@ -292,6 +285,7 @@ ephy_header_bar_constructed (GObject *object)
     remove_menu_item (menu, "app.help");
     remove_menu_item (menu, "app.firefox-sync-dialog");
     remove_menu_item (menu, "import-export");
+    remove_menu_item (menu, "webapps");
   } else if (ephy_is_running_inside_sandbox ()) {
     remove_menu_item (menu, "app.run-in-background");
 
