@@ -108,62 +108,51 @@ option_version_cb (const gchar  *option_name,
 
 /* If you're modifying this array then you need to update the manpage. */
 static const GOptionEntry option_entries[] = {
-  { "new-window", 0, 0, G_OPTION_ARG_NONE, &open_in_new_window,
-    N_("Open a new browser window instead of a new tab"), NULL },
-  { "load-session", 'l', 0, G_OPTION_ARG_FILENAME, &session_filename,
-    N_("Load the given session state file"), N_("FILE") },
-  { "incognito-mode", 'i', 0, G_OPTION_ARG_NONE, &incognito_mode,
-    N_("Start an instance with user data read-only"), NULL },
-  { "private-instance", 'p', 0, G_OPTION_ARG_NONE, &private_instance,
-    N_("Start a private instance with separate user data"), NULL },
-  { "application-mode", 'a', G_OPTION_FLAG_FILENAME | G_OPTION_FLAG_OPTIONAL_ARG,
+  {
+    "new-window", 0, 0, G_OPTION_ARG_NONE, &open_in_new_window,
+    N_("Open a new browser window instead of a new tab"), NULL
+  },
+  {
+    "load-session", 'l', 0, G_OPTION_ARG_FILENAME, &session_filename,
+    N_("Load the given session state file"), N_("FILE")
+  },
+  {
+    "incognito-mode", 'i', 0, G_OPTION_ARG_NONE, &incognito_mode,
+    N_("Start an instance with user data read-only"), NULL
+  },
+  {
+    "private-instance", 'p', 0, G_OPTION_ARG_NONE, &private_instance,
+    N_("Start a private instance with separate user data"), NULL
+  },
+  {
+    "application-mode", 'a', G_OPTION_FLAG_FILENAME | G_OPTION_FLAG_OPTIONAL_ARG,
     G_OPTION_ARG_CALLBACK, application_mode_cb,
-    N_("Start a private instance in web application mode"), NULL },
-  { "automation-mode", 0, 0, G_OPTION_ARG_NONE, &automation_mode,
-    N_("Start a private instance for WebDriver control"), NULL },
-  { "profile", 0, 0, G_OPTION_ARG_STRING, &profile_directory,
-    N_("Custom profile directory for private instance"), N_("DIR") },
-  { G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &arguments,
-    "", N_("URL …") },
-  { "version", 0, G_OPTION_FLAG_NO_ARG | G_OPTION_FLAG_HIDDEN,
-    G_OPTION_ARG_CALLBACK, option_version_cb, NULL, NULL },
-  { "delete-application", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING,
-    &application_to_delete, NULL, NULL },
+    N_("Start a private instance in web application mode"), NULL
+  },
+  {
+    "automation-mode", 0, 0, G_OPTION_ARG_NONE, &automation_mode,
+    N_("Start a private instance for WebDriver control"), NULL
+  },
+  {
+    "profile", 0, 0, G_OPTION_ARG_STRING, &profile_directory,
+    N_("Custom profile directory for private instance"), N_("DIR")
+  },
+  {
+    G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &arguments,
+    "", N_("URL …")
+  },
+  {
+    "version", 0, G_OPTION_FLAG_NO_ARG | G_OPTION_FLAG_HIDDEN,
+    G_OPTION_ARG_CALLBACK, option_version_cb, NULL, NULL
+  },
+  {
+    "delete-application", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING,
+    &application_to_delete, NULL, NULL
+  },
   { "search", 0, 0, G_OPTION_ARG_STRING, &search_term, NULL, NULL},
   { NULL }
 };
 
-/* adapted from gtk+/gdk/x11/gdkdisplay-x11.c */
-static guint32
-get_startup_id (void)
-{
-  const char *startup_id, *time_str;
-  guint32 retval = 0;
-
-  startup_id = g_getenv ("DESKTOP_STARTUP_ID");
-  if (startup_id == NULL)
-    return 0;
-
-  /* Find the launch time from the startup_id, if it's there.  Newer spec
-   * states that the startup_id is of the form <unique>_TIME<timestamp>
-   */
-  time_str = g_strrstr (startup_id, "_TIME");
-  if (time_str != NULL) {
-    gulong value;
-    gchar *end;
-    errno = 0;
-
-    /* Skip past the "_TIME" part */
-    time_str += 5;
-
-    value = strtoul (time_str, &end, 0);
-    if (end != time_str && errno == 0)
-      retval = (guint32)value;
-  }
-
-  return retval;
-}
-
 static void
 maximize_fd_limit (void)
 {
@@ -193,7 +182,6 @@ main (int   argc,
   GOptionContext *option_context;
   GOptionGroup *option_group;
   GError *error = NULL;
-  guint32 user_time;
   gboolean arbitrary_url;
   EphyShellStartupContext *ctx;
   EphyEmbedShellMode mode;
@@ -217,6 +205,8 @@ main (int   argc,
    */
   LIBXML_TEST_VERSION;
 
+  ephy_debug_set_fatal_criticals ();
+
   /* If we're given -remote arguments, translate them */
   if (argc >= 2 && strcmp (argv[1], "-remote") == 0) {
     const char *opening, *closing;
@@ -268,12 +258,9 @@ main (int   argc,
     g_strfreev (arg_list);
   }
 
-  /* Initialise our debug helpers */
+  /* Initialize our debug helpers */
   ephy_debug_init ();
 
-  /* get this early, since gdk will unset the env var */
-  user_time = get_startup_id ();
-
   option_context = g_option_context_new ("");
   option_group = g_option_group_new ("epiphany",
                                      N_("Web"),
@@ -447,8 +434,7 @@ main (int   argc,
 
   ctx = ephy_shell_startup_context_new (open_in_new_window ? EPHY_STARTUP_NEW_WINDOW : EPHY_STARTUP_NEW_TAB,
                                         session_filename,
-                                        arguments,
-                                        user_time);
+                                        arguments);
   g_strfreev (arguments);
   ephy_shell = ephy_shell_get_default ();
   ephy_shell_set_startup_context (ephy_shell, ctx);
