@@ -220,17 +220,15 @@ certificate_button_clicked_cb (GtkButton *button,
                                gpointer   user_data)
 {
   EphySecurityPopover *popover = EPHY_SECURITY_POPOVER (user_data);
-  GtkWidget *dialog;
+  AdwDialog *dialog;
 
-  dialog = ephy_certificate_dialog_new (GTK_WINDOW (gtk_widget_get_root (GTK_WIDGET (popover))),
-                                        popover->address,
+  dialog = ephy_certificate_dialog_new (popover->address,
                                         popover->certificate,
                                         popover->tls_errors,
                                         popover->security_level);
-  gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
+  adw_dialog_present (dialog, GTK_WIDGET (gtk_widget_get_root (GTK_WIDGET (popover))));
   gtk_popover_popdown (GTK_POPOVER (popover));
-  gtk_window_present (GTK_WINDOW (dialog));
 }
 
 static void
@@ -532,8 +530,8 @@ ephy_security_popover_init (EphySecurityPopover *popover)
   popover->host_label = gtk_label_new (NULL);
   gtk_label_set_wrap (GTK_LABEL (popover->host_label), TRUE);
   gtk_label_set_wrap_mode (GTK_LABEL (popover->host_label), PANGO_WRAP_WORD_CHAR);
-  gtk_label_set_max_width_chars (GTK_LABEL (popover->host_label), 0);
   gtk_label_set_xalign (GTK_LABEL (popover->host_label), 0.0);
+  gtk_widget_set_hexpand (popover->host_label, TRUE);
   gtk_box_append (GTK_BOX (box), popover->host_label);
 
   popover->security_label = gtk_label_new (NULL);
