@@ -47,6 +47,8 @@ typedef enum
 
 EphyWindow       *ephy_window_new                 (void);
 
+EphyEmbed        *ephy_window_get_active_embed    (EphyWindow *window);
+
 EphyTabView      *ephy_window_get_tab_view        (EphyWindow *window);
 
 void              ephy_window_toggle_tab_overview (EphyWindow *window);
@@ -97,9 +99,13 @@ void              ephy_window_sync_bookmark_state        (EphyWindow
 
 guint64           ephy_window_get_uid                    (EphyWindow *window);
 
+gboolean          ephy_window_get_sidebar_shown          (EphyWindow *window);
+
 void              ephy_window_switch_to_new_tab_toast    (EphyWindow *window,
                                                           GtkWidget  *tab);
 
 void              ephy_window_switch_to_new_tab          (EphyWindow *window);
 
+void              ephy_window_toggle_bookmarks           (EphyWindow *window);
+
 G_END_DECLS
