@@ -188,9 +188,11 @@ typedef struct {
 } ContextMap;
 
 static const ContextMap context_map[] = {
-  { "all", MENU_CONTEXT_AUDIO | MENU_CONTEXT_BROWSER_ACTION | MENU_CONTEXT_EDITABLE | MENU_CONTEXT_FRAME |
+  {
+    "all", MENU_CONTEXT_AUDIO | MENU_CONTEXT_BROWSER_ACTION | MENU_CONTEXT_EDITABLE | MENU_CONTEXT_FRAME |
     MENU_CONTEXT_IMAGE | MENU_CONTEXT_LINK | MENU_CONTEXT_PAGE | MENU_CONTEXT_PASSWORD |
-    MENU_CONTEXT_SELECTION | MENU_CONTEXT_VIDEO | MENU_CONTEXT_PAGE_ACTION },
+    MENU_CONTEXT_SELECTION | MENU_CONTEXT_VIDEO | MENU_CONTEXT_PAGE_ACTION
+  },
   { "audio", MENU_CONTEXT_AUDIO },
   { "bookmark", MENU_CONTEXT_BOOKMARK },
   { "browser_action", MENU_CONTEXT_BROWSER_ACTION },
