@@ -44,6 +44,9 @@ void window_cmd_show_history                    (GSimpleAction *action,
 void window_cmd_show_firefox_sync               (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
+void window_cmd_show_clear_data_view            (GSimpleAction *action,
+                                                 GVariant      *parameter,
+                                                 gpointer       user_data);
 void window_cmd_show_preferences                (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
@@ -239,5 +242,10 @@ void window_cmd_import_passwords                (GSimpleAction *action,
 void window_cmd_switch_new_tab                  (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
-
+void window_cmd_privacy_report                  (GSimpleAction *action,
+                                                 GVariant      *parameter,
+                                                 gpointer       user_data);
+void window_cmd_export_passwords                (GSimpleAction *action,
+                                                 GVariant      *parameter,
+                                                 gpointer       user_data);
 G_END_DECLS
